Learn R Programming

GBcurves (version 0.1.6)

yields: Yield Curves Dataset

Description

This function downloads daily yield curves data of Brazil, China, and Russia. If necessary, it interpolates with spline function for unavailable maturities.

Usage

yields(init, fin, mty, ctry)

Arguments

init

Initial date in format "YYYY-MM-DD"

fin

Final date in format "YYYY-MM-DD"

mty

Maturities specified by months

ctry

Countries available: "BR", "CN" or "RU"

Value

A matrix that contains daily yield curves in percent in each row and maturities in months by columns.

Examples

Run this code
# NOT RUN {
init <- "2020-05-10"
fin <- "2020-05-17"
mty <- c(3,6,12,120,360)
ctry <- "BR"

# }
# NOT RUN {
yields(init = init, fin = fin, mty = mty, ctry = ctry)
# }

Run the code above in your browser using DataLab